export default {
    /**
     * 添加单位
     * @param num
     * @param unit
     * @returns {string}
     */
    addUnit(num, unit = 'px') {
        return (/px$/.test(num)) ? num : num + unit;
    },
    /**
     * 转换成px
     * 和upx2px区别是可带单位
     * @param num
     * @returns {string}
     */
    getPx(num, isUnit = true) {
        return this.addUnit((
            /(rpx|upx)$/.test(num))
            ? uni.upx2px(parseFloat(num))
            : parseFloat(num), isUnit ? 'px' : '');
    },

    /**
     * 样式转换格式
     * @param customStyle
     * @param target
     * @returns {{}|*|string|string}
     */
    addStyle(customStyle, target = 'object') {
        // 字符串转字符串，对象转对象情形，直接返回
        if (this.empty(customStyle) || typeof (customStyle) === 'object' && target === 'object' || target === 'string' &&
            typeof (customStyle) === 'string') {
            return customStyle
        }
        // 字符串转对象
        if (target === 'object') {
            // 去除字符串样式中的两端空格(中间的空格不能去掉，比如padding: 20px 0如果去掉了就错了)，空格是无用的
            customStyle = this.trim(customStyle)
            // 根据";"将字符串转为数组形式
            const styleArray = customStyle.split(';')
            const style = {}
            // 历遍数组，拼接成对象
            for (let i = 0; i < styleArray.length; i++) {
                // 'font-size:20px;color:red;'，如此最后字符串有";"的话，会导致styleArray最后一个元素为空字符串，这里需要过滤
                if (styleArray[i]) {
                    const item = styleArray[i].split(':')
                    style[this.trim(item[0])] = this.trim(item[1])
                }
            }
            return style
        }
        // 这里为对象转字符串形式
        let string = ''
        for (const i in customStyle) {
            // 驼峰转为中划线的形式，否则css内联样式，无法识别驼峰样式属性名
            const key = i.replace(/([A-Z])/g, '-$1').toLowerCase()
            string += `${key}:${customStyle[i]};`
        }
        // 去除两端空格
        return this.trim(string)
    },
    /**
     * 判断是否为空
     */
    empty(value) {
        switch (typeof value) {
            case 'undefined':
                return true
            case 'string':
                if (value.replace(/(^[ \t\n\r]*)|([ \t\n\r]*$)/g, '').length == 0) return true
                break
            case 'boolean':
                if (!value) return true
                break
            case 'number':
                if (value === 0 || isNaN(value)) return true
                break
            case 'object':
                if (value === null || value.length === 0) return true
                for (const i in value) {
                    return false
                }
                return true
        }
        return false
    },
    /**
     * @description 去除空格
     * @param str
     * @param pos
     */
    trim(str, pos = 'both') {
        str = String(str)
        if (pos == 'both') {
            return str.replace(/^\s+|\s+$/g, '')
        }
        if (pos == 'left') {
            return str.replace(/^\s*/, '')
        }
        if (pos == 'right') {
            return str.replace(/(\s*$)/g, '')
        }
        if (pos == 'all') {
            return str.replace(/\s+/g, '')
        }
        return str
    },
    /**
     * @description 格式化时间
     * @param {String|Number} dateTime 需要格式化的时间戳
     * @param {String} fmt 格式化规则 yyyy:mm:dd|yyyy:mm|yyyy年mm月dd日|yyyy年mm月dd日 hh时MM分等,可自定义组合 默认yyyy-mm-dd
     * @returns {string} 返回格式化后的字符串
     */
    timeFormat(dateTime = null, formatStr = 'yyyy-mm-dd') {
        let date
        // 若传入时间为假值，则取当前时间
        if (!dateTime) {
            date = new Date()
        }
        // 若为unix秒时间戳，则转为毫秒时间戳（逻辑有点奇怪，但不敢改，以保证历史兼容）
        else if (/^\d{10}$/.test(dateTime.toString().trim())) {
            date = new Date(dateTime * 1000)
        }
        // 若用户传入字符串格式时间戳，new Date无法解析，需做兼容
        else if (typeof dateTime === 'string' && /^\d+$/.test(dateTime.trim())) {
            date = new Date(Number(dateTime))
        }
        // 其他都认为符合 RFC 2822 规范
        else {
            // 处理平台性差异，在Safari/Webkit中，new Date仅支持/作为分割符的字符串时间
            date = new Date(
                typeof dateTime === 'string'
                    ? dateTime.replace(/-/g, '/')
                    : dateTime
            )
        }

        const timeSource = {
            'y': date.getFullYear().toString(), // 年
            'm': (date.getMonth() + 1).toString().padStart(2, '0'), // 月
            'd': date.getDate().toString().padStart(2, '0'), // 日
            'h': date.getHours().toString().padStart(2, '0'), // 时
            'M': date.getMinutes().toString().padStart(2, '0'), // 分
            's': date.getSeconds().toString().padStart(2, '0') // 秒
            // 有其他格式化字符需求可以继续添加，必须转化成字符串
        }

        for (const key in timeSource) {
            const [ret] = new RegExp(`${key}+`).exec(formatStr) || []
            if (ret) {
                // 年可能只需展示两位
                const beginIndex = key === 'y' && ret.length === 2 ? 2 : 0
                formatStr = formatStr.replace(ret, timeSource[key].slice(beginIndex))
            }
        }

        return formatStr
    },
    deepClone(data){
        return JSON.parse(JSON.stringify(data));
    },
    downloadFile(url,name){
        new Promise((resolve, reject) => {
            let dTask = plus.downloader.createDownload(url, {
                filename: 'file://storage/emulated/0/阅文系统/' + name
            }, (d, status) => {
                //d为下载的文件对象
                if (status === 200) {
                    resolve('file://storage/emulated/0/阅文系统/' + name);
                } else {
                    reject();
                }
            })
            dTask.start();
        })
    },
    getDirFile(name){
        return new Promise((resolve, reject) => {
            plus.io.requestFileSystem(plus.io.PRIVATE_DOC, function (fs) {
                fs.root.getDirectory('阅文系统/' + name, {}, function (entry) {
                    entry.createReader().readEntries(function (entries) {
                        resolve(entries);
                    }, function (err) {
                        console.log('entries', err)
                        reject();
                    });
                }, function (err) {
                    console.log('entry', err)
                    reject();
                });
            }, function (err) {
                console.log('fs', err)
                reject();
            })
        })
    },
    checkFile(name){
        return new Promise((resolve, reject) => {
            plus.io.requestFileSystem(plus.io.PRIVATE_DOC, function (fs) {
                fs.root.getFile('阅文系统/' + name, {}, function (entry) {
                    console.log(entry)
                    resolve();
                }, function (err) {
                    console.log('entry', err)
                    reject();
                });
            }, function (err) {
                console.log('fs', err)
                reject();
            })
        })
    },
};

